mirror of
https://github.com/neogeek23/rusty_snek_gaem.git
synced 2026-03-22 09:49:38 +00:00
81 lines
17 KiB
HTML
81 lines
17 KiB
HTML
|
|
<!DOCTYPE html><html lang="en"><head><meta charset="utf-8"><meta name="viewport" content="width=device-width, initial-scale=1.0"><meta name="generator" content="rustdoc"><meta name="description" content="API documentation for the Rust `rtentry` struct in crate `libc`."><meta name="keywords" content="rust, rustlang, rust-lang, rtentry"><title>libc::rtentry - Rust</title><link rel="stylesheet" type="text/css" href="../normalize.css"><link rel="stylesheet" type="text/css" href="../rustdoc.css" id="mainThemeStyle"><link rel="stylesheet" type="text/css" href="../dark.css"><link rel="stylesheet" type="text/css" href="../light.css" id="themeStyle"><script src="../storage.js"></script><link rel="shortcut icon" href="https://doc.rust-lang.org/favicon.ico"></head><body class="rustdoc struct"><!--[if lte IE 8]><div class="warning">This old browser is unsupported and will most likely display funky things.</div><![endif]--><nav class="sidebar"><div class="sidebar-menu">☰</div><a href='../libc/index.html'><img src='https://www.rust-lang.org/logos/rust-logo-128x128-blk-v2.png' alt='logo' width='100'></a><p class='location'>Struct rtentry</p><div class="sidebar-elems"><div class="block items"><a class="sidebar-title" href="#fields">Fields</a><div class="sidebar-links"><a href="#structfield.rt_pad1">rt_pad1</a><a href="#structfield.rt_dst">rt_dst</a><a href="#structfield.rt_gateway">rt_gateway</a><a href="#structfield.rt_genmask">rt_genmask</a><a href="#structfield.rt_flags">rt_flags</a><a href="#structfield.rt_pad2">rt_pad2</a><a href="#structfield.rt_pad3">rt_pad3</a><a href="#structfield.rt_tos">rt_tos</a><a href="#structfield.rt_class">rt_class</a><a href="#structfield.rt_pad4">rt_pad4</a><a href="#structfield.rt_metric">rt_metric</a><a href="#structfield.rt_dev">rt_dev</a><a href="#structfield.rt_mtu">rt_mtu</a><a href="#structfield.rt_window">rt_window</a><a href="#structfield.rt_irtt">rt_irtt</a></div><a class="sidebar-title" href="#implementations">Trait Implementations</a><div class="sidebar-links"><a href="#impl-Copy">Copy</a><a href="#impl-Clone">Clone</a></div><a class="sidebar-title" href="#synthetic-implementations">Auto Trait Implementations</a><div class="sidebar-links"><a href="#impl-Send">!Send</a><a href="#impl-Sync">!Sync</a></div></div><p class='location'><a href='index.html'>libc</a></p><script>window.sidebarCurrent = {name: 'rtentry', ty: 'struct', relpath: ''};</script><script defer src="sidebar-items.js"></script></div></nav><div class="theme-picker"><button id="theme-picker" aria-label="Pick another theme!"><img src="../brush.svg" width="18" alt="Pick another theme!"></button><div id="theme-choices"></div></div><script src="../theme.js"></script><nav class="sub"><form class="search-form js-only"><div class="search-container"><input class="search-input" name="search" autocomplete="off" placeholder="Click or press ‘S’ to search, ‘?’ for more options…" type="search"><a id="settings-menu" href="../settings.html"><img src="../wheel.svg" width="18" alt="Change settings"></a></div></form></nav><section id="main" class="content"><h1 class='fqn'><span class='in-band'>Struct <a href='index.html'>libc</a>::<wbr><a class="struct" href=''>rtentry</a></span><span class='out-of-band'><span id='render-detail'><a id="toggle-all-docs" href="javascript:void(0)" title="collapse all docs">[<span class='inner'>−</span>]</a></span><a class='srclink' href='../src/libc/macros.rs.html#42' title='goto source code'>[src]</a></span></h1><div class="docblock type-decl"><pre class='rust struct'><div class="docblock attributes">#[repr(C)]
|
|||
|
|
</div>pub struct rtentry {
|
|||
|
|
pub rt_pad1: <a class="type" href="../libc/type.c_ulong.html" title="type libc::c_ulong">c_ulong</a>,
|
|||
|
|
pub rt_dst: <a class="struct" href="../libc/struct.sockaddr.html" title="struct libc::sockaddr">sockaddr</a>,
|
|||
|
|
pub rt_gateway: <a class="struct" href="../libc/struct.sockaddr.html" title="struct libc::sockaddr">sockaddr</a>,
|
|||
|
|
pub rt_genmask: <a class="struct" href="../libc/struct.sockaddr.html" title="struct libc::sockaddr">sockaddr</a>,
|
|||
|
|
pub rt_flags: <a class="type" href="../libc/type.c_ushort.html" title="type libc::c_ushort">c_ushort</a>,
|
|||
|
|
pub rt_pad2: <a class="type" href="../libc/type.c_short.html" title="type libc::c_short">c_short</a>,
|
|||
|
|
pub rt_pad3: <a class="type" href="../libc/type.c_ulong.html" title="type libc::c_ulong">c_ulong</a>,
|
|||
|
|
pub rt_tos: <a class="type" href="../libc/type.c_uchar.html" title="type libc::c_uchar">c_uchar</a>,
|
|||
|
|
pub rt_class: <a class="type" href="../libc/type.c_uchar.html" title="type libc::c_uchar">c_uchar</a>,
|
|||
|
|
pub rt_pad4: <a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.array.html">[</a><a class="type" href="../libc/type.c_short.html" title="type libc::c_short">c_short</a><a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.array.html">; 3]</a>,
|
|||
|
|
pub rt_metric: <a class="type" href="../libc/type.c_short.html" title="type libc::c_short">c_short</a>,
|
|||
|
|
pub rt_dev: <a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.pointer.html">*mut </a><a class="type" href="../libc/type.c_char.html" title="type libc::c_char">c_char</a>,
|
|||
|
|
pub rt_mtu: <a class="type" href="../libc/type.c_ulong.html" title="type libc::c_ulong">c_ulong</a>,
|
|||
|
|
pub rt_window: <a class="type" href="../libc/type.c_ulong.html" title="type libc::c_ulong">c_ulong</a>,
|
|||
|
|
pub rt_irtt: <a class="type" href="../libc/type.c_ushort.html" title="type libc::c_ushort">c_ushort</a>,
|
|||
|
|
}</pre></div><h2 id='fields' class='fields small-section-header'>
|
|||
|
|
Fields<a href='#fields' class='anchor'></a></h2><span id="structfield.rt_pad1" class="structfield small-section-header">
|
|||
|
|
<a href="#structfield.rt_pad1" class="anchor field"></a>
|
|||
|
|
<span id="rt_pad1.v" class='invisible'>
|
|||
|
|
<code>rt_pad1: <a class="type" href="../libc/type.c_ulong.html" title="type libc::c_ulong">c_ulong</a></code>
|
|||
|
|
</span></span><span id="structfield.rt_dst" class="structfield small-section-header">
|
|||
|
|
<a href="#structfield.rt_dst" class="anchor field"></a>
|
|||
|
|
<span id="rt_dst.v" class='invisible'>
|
|||
|
|
<code>rt_dst: <a class="struct" href="../libc/struct.sockaddr.html" title="struct libc::sockaddr">sockaddr</a></code>
|
|||
|
|
</span></span><span id="structfield.rt_gateway" class="structfield small-section-header">
|
|||
|
|
<a href="#structfield.rt_gateway" class="anchor field"></a>
|
|||
|
|
<span id="rt_gateway.v" class='invisible'>
|
|||
|
|
<code>rt_gateway: <a class="struct" href="../libc/struct.sockaddr.html" title="struct libc::sockaddr">sockaddr</a></code>
|
|||
|
|
</span></span><span id="structfield.rt_genmask" class="structfield small-section-header">
|
|||
|
|
<a href="#structfield.rt_genmask" class="anchor field"></a>
|
|||
|
|
<span id="rt_genmask.v" class='invisible'>
|
|||
|
|
<code>rt_genmask: <a class="struct" href="../libc/struct.sockaddr.html" title="struct libc::sockaddr">sockaddr</a></code>
|
|||
|
|
</span></span><span id="structfield.rt_flags" class="structfield small-section-header">
|
|||
|
|
<a href="#structfield.rt_flags" class="anchor field"></a>
|
|||
|
|
<span id="rt_flags.v" class='invisible'>
|
|||
|
|
<code>rt_flags: <a class="type" href="../libc/type.c_ushort.html" title="type libc::c_ushort">c_ushort</a></code>
|
|||
|
|
</span></span><span id="structfield.rt_pad2" class="structfield small-section-header">
|
|||
|
|
<a href="#structfield.rt_pad2" class="anchor field"></a>
|
|||
|
|
<span id="rt_pad2.v" class='invisible'>
|
|||
|
|
<code>rt_pad2: <a class="type" href="../libc/type.c_short.html" title="type libc::c_short">c_short</a></code>
|
|||
|
|
</span></span><span id="structfield.rt_pad3" class="structfield small-section-header">
|
|||
|
|
<a href="#structfield.rt_pad3" class="anchor field"></a>
|
|||
|
|
<span id="rt_pad3.v" class='invisible'>
|
|||
|
|
<code>rt_pad3: <a class="type" href="../libc/type.c_ulong.html" title="type libc::c_ulong">c_ulong</a></code>
|
|||
|
|
</span></span><span id="structfield.rt_tos" class="structfield small-section-header">
|
|||
|
|
<a href="#structfield.rt_tos" class="anchor field"></a>
|
|||
|
|
<span id="rt_tos.v" class='invisible'>
|
|||
|
|
<code>rt_tos: <a class="type" href="../libc/type.c_uchar.html" title="type libc::c_uchar">c_uchar</a></code>
|
|||
|
|
</span></span><span id="structfield.rt_class" class="structfield small-section-header">
|
|||
|
|
<a href="#structfield.rt_class" class="anchor field"></a>
|
|||
|
|
<span id="rt_class.v" class='invisible'>
|
|||
|
|
<code>rt_class: <a class="type" href="../libc/type.c_uchar.html" title="type libc::c_uchar">c_uchar</a></code>
|
|||
|
|
</span></span><span id="structfield.rt_pad4" class="structfield small-section-header">
|
|||
|
|
<a href="#structfield.rt_pad4" class="anchor field"></a>
|
|||
|
|
<span id="rt_pad4.v" class='invisible'>
|
|||
|
|
<code>rt_pad4: <a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.array.html">[</a><a class="type" href="../libc/type.c_short.html" title="type libc::c_short">c_short</a><a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.array.html">; 3]</a></code>
|
|||
|
|
</span></span><span id="structfield.rt_metric" class="structfield small-section-header">
|
|||
|
|
<a href="#structfield.rt_metric" class="anchor field"></a>
|
|||
|
|
<span id="rt_metric.v" class='invisible'>
|
|||
|
|
<code>rt_metric: <a class="type" href="../libc/type.c_short.html" title="type libc::c_short">c_short</a></code>
|
|||
|
|
</span></span><span id="structfield.rt_dev" class="structfield small-section-header">
|
|||
|
|
<a href="#structfield.rt_dev" class="anchor field"></a>
|
|||
|
|
<span id="rt_dev.v" class='invisible'>
|
|||
|
|
<code>rt_dev: <a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.pointer.html">*mut </a><a class="type" href="../libc/type.c_char.html" title="type libc::c_char">c_char</a></code>
|
|||
|
|
</span></span><span id="structfield.rt_mtu" class="structfield small-section-header">
|
|||
|
|
<a href="#structfield.rt_mtu" class="anchor field"></a>
|
|||
|
|
<span id="rt_mtu.v" class='invisible'>
|
|||
|
|
<code>rt_mtu: <a class="type" href="../libc/type.c_ulong.html" title="type libc::c_ulong">c_ulong</a></code>
|
|||
|
|
</span></span><span id="structfield.rt_window" class="structfield small-section-header">
|
|||
|
|
<a href="#structfield.rt_window" class="anchor field"></a>
|
|||
|
|
<span id="rt_window.v" class='invisible'>
|
|||
|
|
<code>rt_window: <a class="type" href="../libc/type.c_ulong.html" title="type libc::c_ulong">c_ulong</a></code>
|
|||
|
|
</span></span><span id="structfield.rt_irtt" class="structfield small-section-header">
|
|||
|
|
<a href="#structfield.rt_irtt" class="anchor field"></a>
|
|||
|
|
<span id="rt_irtt.v" class='invisible'>
|
|||
|
|
<code>rt_irtt: <a class="type" href="../libc/type.c_ushort.html" title="type libc::c_ushort">c_ushort</a></code>
|
|||
|
|
</span></span><h2 id='implementations' class='small-section-header'>Trait Implementations<a href='#implementations' class='anchor'></a></h2><div id='implementations-list'><h3 id='impl-Copy' class='impl'><span class='in-band'><table class='table-display'><tbody><tr><td><code>impl <a class="trait" href="https://doc.rust-lang.org/nightly/core/marker/trait.Copy.html" title="trait core::marker::Copy">Copy</a> for <a class="struct" href="../libc/struct.rtentry.html" title="struct libc::rtentry">rtentry</a></code><a href='#impl-Copy' class='anchor'></a></span></td><td><span class='out-of-band'><div class='ghost'></div><a class='srclink' href='../src/libc/macros.rs.html#44' title='goto source code'>[src]</a></span></td></tr></tbody></table></h3><div class='impl-items'></div><h3 id='impl-Clone' class='impl'><span class='in-band'><table class='table-display'><tbody><tr><td><code>impl <a class="trait" href="https://doc.rust-lang.org/nightly/core/clone/trait.Clone.html" title="trait core::clone::Clone">Clone</a> for <a class="struct" href="../libc/struct.rtentry.html" title="struct libc::rtentry">rtentry</a></code><a href='#impl-Clone' class='anchor'></a></span></td><td><span class='out-of-band'><div class='ghost'></div><a class='srclink' href='../src/libc/macros.rs.html#45-47' title='goto source code'>[src]</a></span></td></tr></tbody></table></h3><div class='impl-items'><h4 id='method.clone' class="method"><span id='clone.v' class='invisible'><table class='table-display'><tbody><tr><td><code>fn <a href='https://doc.rust-lang.org/nightly/core/clone/trait.Clone.html#tymethod.clone' class='fnname'>clone</a>(&self) -> <a class="struct" href="../libc/struct.rtentry.html" title="struct libc::rtentry">rtentry</a></code></span></td><td><span class='out-of-band'><div class='ghost'></div><a class='srclink' href='../src/libc/macros.rs.html#46' title='goto source code'>[src]</a></td></tr></tbody></table></span></h4><div class='docblock'><p>Returns a copy of the value. <a href="https://doc.rust-lang.org/nightly/core/clone/trait.Clone.html#tymethod.clone">Read more</a></p>
|
|||
|
|
</div><h4 id='method.clone_from' class="method"><span id='clone_from.v' class='invisible'><table class='table-display'><tbody><tr><td><code>fn <a href='https://doc.rust-lang.org/nightly/core/clone/trait.Clone.html#method.clone_from' class='fnname'>clone_from</a>(&mut self, source: <a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.reference.html">&</a>Self)</code></span></td><td><span class='out-of-band'><div class='ghost'></div><div class='since' title='Stable since Rust version 1.0.0'>1.0.0</div><a class='srclink' href='https://doc.rust-lang.org/nightly/src/core/clone.rs.html#130-132' title='goto source code'>[src]</a></td></tr></tbody></table></span></h4><div class='docblock'><p>Performs copy-assignment from <code>source</code>. <a href="https://doc.rust-lang.org/nightly/core/clone/trait.Clone.html#method.clone_from">Read more</a></p>
|
|||
|
|
</div></div></div><h2 id='synthetic-implementations' class='small-section-header'>Auto Trait Implementations<a href='#synthetic-implementations' class='anchor'></a></h2><div id='synthetic-implementations-list'><h3 id='impl-Send' class='impl'><span class='in-band'><table class='table-display'><tbody><tr><td><code>impl !<a class="trait" href="https://doc.rust-lang.org/nightly/core/marker/trait.Send.html" title="trait core::marker::Send">Send</a> for <a class="struct" href="../libc/struct.rtentry.html" title="struct libc::rtentry">rtentry</a></code><a href='#impl-Send' class='anchor'></a></span></td><td><span class='out-of-band'></span></td></tr></tbody></table></h3><div class='impl-items'></div><h3 id='impl-Sync' class='impl'><span class='in-band'><table class='table-display'><tbody><tr><td><code>impl !<a class="trait" href="https://doc.rust-lang.org/nightly/core/marker/trait.Sync.html" title="trait core::marker::Sync">Sync</a> for <a class="struct" href="../libc/struct.rtentry.html" title="struct libc::rtentry">rtentry</a></code><a href='#impl-Sync' class='anchor'></a></span></td><td><span class='out-of-band'></span></td></tr></tbody></table></h3><div class='impl-items'></div></div></section><section id="search" class="content hidden"></section><section class="footer"></section><aside id="help" class="hidden"><div><h1 class="hidden">Help</h1><div class="shortcuts"><h2>Keyboard Shortcuts</h2><dl><dt><kbd>?</kbd></dt><dd>Show this help dialog</dd><dt><kbd>S</kbd></dt><dd>Focus the search field</dd><dt><kbd>↑</kbd></dt><dd>Move up in search results</dd><dt><kbd>↓</kbd></dt><dd>Move down in search results</dd><dt><kbd>↹</kbd></dt><dd>Switch tab</dd><dt><kbd>⏎</kbd></dt><dd>Go to active search result</dd><dt><kbd>+</kbd></dt><dd>Expand all sections</dd><dt><kbd>-</kbd></dt><dd>Collapse all sections</dd></dl></div><div class="infos"><h2>Search Tricks</h2><p>Prefix searches with a type followed by a colon (e.g. <code>fn:</code>) to restrict the search to a given type.</p><p>Accepted types are: <code>fn</code>, <code>mod</code>, <code>struct</code>, <code>enum</code>, <code>trait</code>, <code>type</code>, <code>macro</code>, and <code>const</code>.</p><p>Search functions by type signature (e.g. <code>vec -> usize</code> or <code>* -> vec</code>)</p><p>Search multiple things at once by splitting your query with comma (e.g. <code>str,u8</code> or <code>String,struct:Vec,test</code>)</p></div></div></aside><script>window.rootPath = "../";window.currentCrate = "libc";</script><script src="../aliases.js"></script><script src="../main.js"></script><script defer src="../search-index.js"></script></body></html>
|