Type Alias c_schar
pub type c_schar = i8;Expand description
Equivalent to C’s signed char type.
This type will always be [i8], but is included for completeness. It is defined as being a signed integer the same size as a C char.
pub type c_schar = i8;Equivalent to C’s signed char type.
This type will always be [i8], but is included for completeness. It is defined as being a signed integer the same size as a C char.