Type Alias c_uchar
pub type c_uchar = u8;Expand description
Equivalent to C’s unsigned char type.
This type will always be [u8], but is included for completeness. It is defined as being an unsigned integer the same size as a C char.
pub type c_uchar = u8;Equivalent to C’s unsigned char type.
This type will always be [u8], but is included for completeness. It is defined as being an unsigned integer the same size as a C char.